#!/bin/bash

######################################################
# Manual preparation before running this...
#
# SAVE ORIGINAL /usr/local AND MOVE IT OUT OF THE WAY
# mv /usr/local /usr/local.save
#
# 
# Install Ghostscript. The non-binaries will become part of this package
# but the binary will be replaced by separately compiled binaries
# Don't install the Ghostscript fonts; the script below will supply them.
#
######################################################

# We're going to run this in the MacTeXDVD working directory...
WORK=`pwd`

if [[ ! -x /usr/local/bin/gs ]]; then
	echo "### error: Ghostscript is missing"
	exit 1
fi

echo "Removing old file tree at ${WORK}/root"
rm -rf ${WORK}/root

# Copy everything from /usr/local into our root
echo "Collecting files from /usr/local"
mkdir -p ${WORK}/root/usr
cp -pRf /usr/local ${WORK}/root/usr

# Deal with TeX fonts

# mkdir -p ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Init
# mkdir -p ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Font
# mkdir -p ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/CIDFont
cp ${WORK}/Bruno1/Fontmap.cmr ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Init/Fontmap.cmr
cp ${WORK}/Bruno1/Fontmap ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Init/Fontmap
cp ${WORK}/Bruno1/Fontmap.MacTeX ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Init/Fontmap.MacTeX
cp -pRf ${WORK}/Bruno1/fonts/*.pfb ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Font

# Deal with KUROKI-Yusuke additions following Bruno Voisin
# Commented out lines were modified in Bruno3

# cp -pRf ${WORK}/Bruno2/Font/* ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Font

# FILES=${WORK}/Bruno2/Font/*
# for file in $FILES
# do
# 	cp -pRf $file ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Font 
# done

# cp -pRf ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Init/cidfmap ${WORK}/Replaced/Init
# cp -pRf ${WORK}/Bruno2/cidfmap ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Init
# cp -pRf ${WORK}/Bruno2/cidfmap.MacTeX ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Init
# cp -pRf ${WORK}/Bruno2/CIDFont/* ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/CIDFont

# Bruno Voisin's Third Take, particularly on Chinese fonts which vary from OS to OS

# cp -pRf ${WORK}/Bruno3/CIDFont/10.9-10/* ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/CIDFont
# cp -pRf ${WORK}/Bruno3/Init/cidfmap.MacTeX10.5-7 ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Init
# cp -pRf ${WORK}/Bruno3/Init/cidfmap.MacTeX10.8 ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Init
# cp -pRf ${WORK}/Bruno3/Init/cidfmap.MacTeX10.9-10 ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Init
# cp -pRf ${WORK}/Bruno3/Init/cidfmap.MacTeX10.9-10 ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Init/cidfmap.MacTeX

# Bruno Voisin's Fourth Take, April 11

FILES1=${WORK}/Bruno4/share/ghostscript/9.16/Resource/Font/*
for file in $FILES1
do
	cp -pRf $file ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Font 
done

FILES2=${WORK}/Bruno4/share/ghostscript/9.16/Resource/CIDFont/*
for file in $FILES2
do
	cp -pRf $file ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/CIDFont 
done
 cp -pRf ${WORK}/Bruno4/share/ghostscript/9.16/Resource/Init/cidfmap ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Init/cidfmap
 cp -pRf ${WORK}/Bruno4/share/ghostscript/9.16/Resource/Init/cidfmap.MacTeX ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Init/cidfmap.MacTeX


# Original KUROKI-Yusuke additions for Japanese

# cp -pRf ${WORK}/KUROKI-Yusuke/CIDFont/* ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/CIDFont
# cp -pRf ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Init/cidfmap ${WORK}/Replaced/Init
# cp -pRf ${WORK}/KUROKI-Yusuke/cidfmap ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Init
# cp -pRf ${WORK}/KUROKI-Yusuke/Font/* ${WORK}/root/usr/local/share/ghostscript/9.16/Resource/Font

# Replace gs binary with binaries compiled on various platforms; active program determined by postinstall script

rm ${WORK}/root/usr/local/bin/gs
cp ${WORK}/Binaries/10.5/gs-noX11 ${WORK}/root/usr/local/bin/gs-noX11
cp ${WORK}/Binaries/10.5/gs-X11 ${WORK}/root/usr/local/bin/gs-X11
cp ${WORK}/Binaries/10.6/gs-X11-64Bit ${WORK}/root/usr/local/bin/gs-X11-64Bit
cp ${WORK}/Binaries/10.6/gs-noX11-64Bit ${WORK}/root/usr/local/bin/gs-noX11-64Bit
cp ${WORK}/Binaries/Yosemite/gs-X11-Yosemite ${WORK}/root/usr/local/bin/gs-X11-Yosemite
cp ${WORK}/Binaries/Yosemite/gs-noX11-Yosemite ${WORK}/root/usr/local/bin/gs-noX11-Yosemite

# chmod
echo "Changing permissions"
chmod -R a+r ${WORK}/root/usr
chown -R root  ${WORK}/root/usr
chgrp -R wheel  ${WORK}/root/usr

chmod 755 ${WORK}/root/usr
chgrp wheel ${WORK}/root/usr


